@@ -8,6 +8,7 @@ from contextlib import contextmanager
 
 import dbt.exceptions
 import dbt.flags
+import dbt.materializers
 
 from dbt.contracts.connection import validate_connection
 from dbt.logger import GLOBAL_LOGGER as logger
@@ -21,6 +22,12 @@ connections_available = []
 
 class DefaultAdapter(object):
 
+    requires = {}
+
+    @classmethod
+    def get_materializer(cls, model, existing):
+        return dbt.materializers.get_materializer(cls, model, existing)
+
     ###
     # ADAPTER-SPECIFIC FUNCTIONS -- each of these must be overridden in
     #                               every adapter
@@ -68,6 +75,16 @@ class DefaultAdapter(object):
         raise dbt.exceptions.NotImplementedException(
             '`query_for_existing` is not implemented for this adapter!')
 
+    @classmethod
+    def check_schema_exists(cls, profile, schema):
+        raise dbt.exceptions.NotImplementedException(
+            '`check_schema_exists` is not implemented for this adapter!')
+
+    @classmethod
+    def cancel_connection(cls, project, connection):
+        raise dbt.exceptions.NotImplementedException(
+            '`cancel_connection` is not implemented for this adapter!')
+
     ###
     # FUNCTIONS THAT SHOULD BE ABSTRACT
     ###
@@ -123,6 +140,10 @@ class DefaultAdapter(object):
 
         connection, cursor = cls.add_query(profile, sql, model_name)
 
+    @classmethod
+    def is_cancelable(cls):
+        return True
+
     @classmethod
     def execute_model(cls, profile, model):
         parts = re.split(r'-- (DBT_OPERATION .*)', model.get('wrapped_sql'))
@@ -233,6 +254,11 @@ class DefaultAdapter(object):
         return ('create schema if not exists "{schema}"'
                 .format(schema=schema))
 
+    @classmethod
+    def get_drop_schema_sql(cls, schema):
+        return ('drop schema if exists "{schema} cascade"'
+                .format(schema=schema))
+
     @classmethod
     def get_create_table_sql(cls, schema, table, columns, sort, dist):
         fields = ['"{field}" {data_type}'.format(
@@ -287,6 +313,17 @@ class DefaultAdapter(object):
 
         return cls.get_connection(profile, name)
 
+    @classmethod
+    def cancel_open_connections(cls, profile):
+        global connections_in_use
+
+        for name, connection in connections_in_use.items():
+            if name == 'master':
+                continue
+
+            cls.cancel_connection(profile, connection)
+            yield name
+
     @classmethod
     def total_connections_allocated(cls):
         global connections_in_use, connections_available
@@ -425,6 +462,9 @@ class DefaultAdapter(object):
     def commit_if_has_connection(cls, profile, name):
         global connections_in_use
 
+        if name is None:
+            name = 'master'
+
         if connections_in_use.get(name) is None:
             return
 
@@ -515,10 +555,17 @@ class DefaultAdapter(object):
             return connection, cursor
 
     @classmethod
-    def execute_one(cls, profile, sql, model_name=None):
+    def execute_one(cls, profile, sql, model_name=None, auto_begin=False):
         cls.get_connection(profile, model_name)
 
-        return cls.add_query(profile, sql, model_name)
+        return cls.add_query(profile, sql, model_name, auto_begin)
+
+    @classmethod
+    def execute_and_fetch(cls, profile, sql, model_name=None,
+                          auto_begin=False):
+        _, cursor = cls.execute_one(profile, sql, model_name, auto_begin)
+
+        return cursor.fetchall()
 
     @classmethod
     def execute_all(cls, profile, sqls, model_name=None):
@@ -536,6 +583,16 @@ class DefaultAdapter(object):
     def create_schema(cls, profile, schema, model_name=None):
         logger.debug('Creating schema "%s".', schema)
         sql = cls.get_create_schema_sql(schema)
+        res = cls.add_query(profile, sql, model_name)
+
+        cls.commit_if_has_connection(profile, model_name)
+
+        return res
+
+    @classmethod
+    def drop_schema(cls, profile, schema, model_name=None):
+        logger.debug('Dropping schema "%s".', schema)
+        sql = cls.get_drop_schema_sql(schema)
         return cls.add_query(profile, sql, model_name)
 
     @classmethod
@@ -557,3 +614,7 @@ class DefaultAdapter(object):
         Alias for `table_exists`.
         """
         return cls.table_exists(profile, schema, table, model_name)
+
+    @classmethod
+    def quote_schema_and_table(cls, profile, schema, table):
+        return '"{}"."{}"'.format(schema, table)
