@@ -2,6 +2,11 @@ import errno
 import fnmatch
 import os
 import os.path
+import shutil
+import subprocess
+import sys
+
+from dbt.logger import GLOBAL_LOGGER as logger
 
 
 def find_matching(root_path,
@@ -70,3 +75,52 @@ def make_directory(path):
                 pass
             else:
                 raise e
+
+
+def make_file(path, contents='', overwrite=False):
+    """
+    Make a file at `path` assuming that the directory it resides in already
+    exists. The file is saved with contents `contents`
+    """
+    if overwrite or not os.path.exists(path):
+        with open(path, 'w') as fh:
+            fh.write(contents)
+        return True
+
+    return False
+
+
+def rmdir(path):
+    """
+    Make a file at `path` assuming that the directory it resides in already
+    exists. The file is saved with contents `contents`
+    """
+    return shutil.rmtree(path)
+
+
+def open_dir_cmd():
+    # https://docs.python.org/2/library/sys.html#sys.platform
+    if sys.platform == 'win32':
+        return 'start'
+
+    elif sys.platform == 'darwin':
+        return 'open'
+
+    else:
+        return 'xdg-open'
+
+
+def run_cmd(cwd, cmd):
+    logger.debug('Executing "{}"'.format(' '.join(cmd)))
+    proc = subprocess.Popen(
+        cmd,
+        cwd=cwd,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE)
+
+    out, err = proc.communicate()
+
+    logger.debug('STDOUT: "{}"'.format(out))
+    logger.debug('STDERR: "{}"'.format(err))
+
+    return out, err
