@@ -11,19 +11,14 @@ class DBTDeprecation(object):
             logger.info("* Deprecation Warning: {}\n".format(desc))
             active_deprecations.add(self.name)
 
-
-class DBTRunTargetDeprecation(DBTDeprecation):
-    name = 'run-target'
-    description = """profiles.yml configuration option 'run-target' is
-    deprecated. Please use 'target' instead. The 'run-target' option will be
-    removed (in favor of 'target') in DBT version 0.7.0"""
-
-
-class DBTInvalidPackageName(DBTDeprecation):
-    name = 'invalid-package-name'
-    description = """The package name '{package_name}' is not valid. Package
-    names must only contain letters and underscores. Packages with invalid
-    names will fail to compile in DBT version 0.7.0"""
+# Leaving this as an example. Make sure to add new ones to deprecations_list
+#       - Connor
+#
+# class DBTRunTargetDeprecation(DBTDeprecation):
+#     name = 'run-target'
+#     description = """profiles.yml configuration option 'run-target' is
+#     deprecated. Please use 'target' instead. The 'run-target' option will be
+#     removed (in favor of 'target') in DBT version 0.7.0"""
 
 
 def warn(name, *args, **kwargs):
@@ -42,8 +37,6 @@ def warn(name, *args, **kwargs):
 active_deprecations = set()
 
 deprecations_list = [
-    DBTRunTargetDeprecation(),
-    DBTInvalidPackageName()
 ]
 
 deprecations = {d.name: d for d in deprecations_list}
