@@ -1,5 +1,4 @@
 from dbt.compat import basestring
-import dbt.utils
 
 
 class Exception(BaseException):
@@ -45,7 +44,7 @@ def raise_compiler_error(node, msg):
         name = node.get('name')
         node_type = node.get('resource_type')
 
-        if node_type == dbt.utils.NodeType.Macro:
+        if node_type == 'macro':
             name = node.get('path')
     else:
         name = node.nice_name
@@ -125,3 +124,9 @@ def missing_sql_where(model):
         model,
         "Model '{}' is materialized as 'incremental', but does not have a "
         "sql_where defined in its config.".format(model.get('unique_id')))
+
+
+def bad_package_spec(repo, spec, error_message):
+    raise RuntimeException(
+        "Error checking out spec='{}' for repo {}\n{}".format(
+            spec, repo, error_message))
