@@ -16,9 +16,19 @@ import dbt.task.init as init_task
 import dbt.task.seed as seed_task
 import dbt.task.test as test_task
 import dbt.task.archive as archive_task
+
 import dbt.tracking
 import dbt.config as config
-import dbt.adapters.cache as adapter_cache
+import dbt.ui.printer
+import dbt.compat
+
+from dbt.utils import ExitCodes
+
+PROFILES_HELP_MESSAGE = """
+For more information on configuring profiles, please consult the dbt docs:
+
+https://dbt.readme.io/docs/configure-your-profile
+"""
 
 
 def main(args=None):
@@ -26,28 +36,54 @@ def main(args=None):
         args = sys.argv[1:]
 
     try:
-        handle(args)
+        results, succeeded = handle_and_check(args)
+        if succeeded:
+            exit_code = ExitCodes.Success
+        else:
+            exit_code = ExitCodes.ModelError
 
-    except RuntimeError as e:
+    except KeyboardInterrupt as e:
+        logger.info("ctrl-c")
+        exit_code = ExitCodes.UnhandledError
+
+    # This can be thrown by eg. argparse
+    except SystemExit as e:
+        exit_code = e.code
+
+    except BaseException as e:
         logger.info("Encountered an error:")
         logger.info(str(e))
-        sys.exit(1)
+        exit_code = ExitCodes.UnhandledError
+
+    sys.exit(exit_code)
 
 
+# here for backwards compatibility
 def handle(args):
+    res, success = handle_and_check(args)
+    return res
+
+
+def handle_and_check(args):
     parsed = parse_args(args)
 
     # this needs to happen after args are parsed so we can determine the
     # correct profiles.yml file
-    if not config.send_anonymous_usage_stats(parsed.profiles_dir):
+    profile_config = config.read_config(parsed.profiles_dir)
+    if not config.send_anonymous_usage_stats(profile_config):
         dbt.tracking.do_not_track()
     else:
         dbt.tracking.initialize_tracking()
 
-    res = run_from_args(parsed)
+    if dbt.config.colorize_output(profile_config):
+        dbt.ui.printer.use_colors()
+
+    task, res = run_from_args(parsed)
     dbt.tracking.flush()
 
-    return res
+    success = task.interpret_results(res)
+
+    return res, success
 
 
 def get_nearest_project_dir():
@@ -96,21 +132,27 @@ def run_from_args(parsed):
 
     dbt.tracking.track_invocation_start(project=proj, args=parsed)
 
+    results = run_from_task(task, proj, parsed)
+
+    return task, results
+
+
+def run_from_task(task, proj, parsed_args):
     result = None
     try:
         result = task.run()
         dbt.tracking.track_invocation_end(
-            project=proj, args=parsed, result_type="ok", result=None
+            project=proj, args=parsed_args, result_type="ok", result=None
         )
     except (dbt.exceptions.NotImplementedException,
             dbt.exceptions.FailedToConnectException) as e:
         logger.info('ERROR: {}'.format(e))
         dbt.tracking.track_invocation_end(
-            project=proj, args=parsed, result_type="error", result=str(e)
+            project=proj, args=parsed_args, result_type="error", result=str(e)
         )
     except Exception as e:
         dbt.tracking.track_invocation_end(
-            project=proj, args=parsed, result_type="error", result=str(e)
+            project=proj, args=parsed_args, result_type="error", result=str(e)
         )
         raise
 
@@ -121,8 +163,6 @@ def invoke_dbt(parsed):
     task = None
     proj = None
 
-    adapter_cache.reset()
-
     try:
         proj = project.read_project(
             'dbt_project.yml',
@@ -134,17 +174,19 @@ def invoke_dbt(parsed):
         proj.validate()
     except project.DbtProjectError as e:
         logger.info("Encountered an error while reading the project:")
-        logger.info("  ERROR {}".format(str(e)))
-        logger.info(
-            "Did you set the correct --profile? Using: {}"
-            .format(parsed.profile))
-
-        logger.info("Valid profiles:")
+        logger.info(dbt.compat.to_string(e))
 
         all_profiles = project.read_profiles(parsed.profiles_dir).keys()
 
-        for profile in all_profiles:
-            logger.info(" - {}".format(profile))
+        if len(all_profiles) > 0:
+            logger.info("Defined profiles:")
+            for profile in all_profiles:
+                logger.info(" - {}".format(profile))
+        else:
+            logger.info("There are no profiles defined in your "
+                        "profiles.yml file")
+
+        logger.info(PROFILES_HELP_MESSAGE)
 
         dbt.tracking.track_invalid_invocation(
             project=proj,
@@ -255,24 +297,14 @@ def parse_args(args):
     sub = subs.add_parser('clean', parents=[base_subparser])
     sub.set_defaults(cls=clean_task.CleanTask, which='clean')
 
-    sub.add_argument(
-        '--non-destructive',
-        action='store_true',
-        help="""
-        If specified, DBT will not drop views. Tables will be truncated instead
-        of dropped.
-        """
-    )
-    sub.add_argument(
-        '--full-refresh',
-        action='store_true',
-        help="""
-        If specified, DBT will drop incremental models and fully-recalculate
-        the incremental table from the model definition.
-        """
-    )
-
     sub = subs.add_parser('debug', parents=[base_subparser])
+    sub.add_argument(
+        '--config-dir',
+        action='store_true',
+        help="""
+        If specified, DBT will show path information for this project
+        """
+    )
     sub.set_defaults(cls=debug_task.DebugTask, which='debug')
 
     sub = subs.add_parser('deps', parents=[base_subparser])
