@@ -6,7 +6,8 @@ from dbt.compat import basestring
 import dbt.flags
 
 from dbt.templates import BaseCreateTemplate
-from dbt.utils import split_path, NodeType
+from dbt.utils import split_path
+from dbt.node_types import NodeType
 import dbt.project
 from dbt.utils import deep_merge, DBTConfigKeys, compiler_error
 
@@ -83,16 +84,8 @@ class SourceConfig(object):
                 defaults, own_config, self.in_model_config, active_config
             )
 
-        # mask this as a table if it's an incremental model with
-        # --full-refresh provided
-        if cfg.get('materialized') == 'incremental' and self.is_full_refresh():
-            cfg['materialized'] = 'table'
-
         return cfg
 
-    def is_full_refresh(self):
-        return dbt.flags.FULL_REFRESH
-
     def update_in_model_config(self, config):
         config = config.copy()
 
