@@ -1,6 +1,5 @@
 import copy
 import os
-import yaml
 import re
 
 import dbt.flags
@@ -9,12 +8,14 @@ import dbt.utils
 
 import jinja2.runtime
 import dbt.clients.jinja
+import dbt.clients.yaml_helper
 
 import dbt.contracts.graph.parsed
 import dbt.contracts.graph.unparsed
 import dbt.contracts.project
 
-from dbt.utils import NodeType, Var
+from dbt.utils import Var
+from dbt.node_types import NodeType, RunHookType
 from dbt.compat import basestring, to_string
 from dbt.logger import GLOBAL_LOGGER as logger
 
@@ -380,7 +381,7 @@ def load_and_parse_run_hook_type(root_project, all_projects, hook_type):
 
 def load_and_parse_run_hooks(root_project, all_projects):
     hook_nodes = {}
-    for hook_type in dbt.utils.RunHookType.Both:
+    for hook_type in RunHookType.Both:
         project_hooks = load_and_parse_run_hook_type(root_project,
                                                      all_projects,
                                                      hook_type)
@@ -426,7 +427,14 @@ def parse_schema_tests(tests, root_project, projects):
     to_return = {}
 
     for test in tests:
-        test_yml = yaml.safe_load(test.get('raw_yml'))
+        raw_yml = test.get('raw_yml')
+        test_name = "{}:{}".format(test.get('package_name'), test.get('path'))
+
+        try:
+            test_yml = dbt.clients.yaml_helper.load_yaml_text(raw_yml)
+        except dbt.exceptions.ValidationException as e:
+            test_yml = None
+            logger.info("Error reading {} - Skipping\n{}".format(test_name, e))
 
         if test_yml is None:
             continue
@@ -551,7 +559,7 @@ def load_and_parse_yml(package_name, root_project, all_projects, root_dir,
 
     for file_match in file_matches:
         file_contents = dbt.clients.system.load_file_contents(
-            file_match.get('absolute_path'))
+            file_match.get('absolute_path'), strip=False)
 
         parts = dbt.utils.split_path(file_match.get('relative_path', ''))
         name, _ = os.path.splitext(parts[-1])
@@ -605,11 +613,12 @@ def parse_archives_from_project(project):
             config['source_schema'] = archive_config.get('source_schema')
             config['target_schema'] = archive_config.get('target_schema')
 
+            fake_path = [config['target_schema'], config['target_table']]
             archives.append({
                 'name': table.get('target_table'),
                 'root_path': project.get('project-root'),
                 'resource_type': NodeType.Archive,
-                'path': project.get('project-root'),
+                'path': os.path.join('archive', *fake_path),
                 'package_name': project.get('name'),
                 'config': config,
                 'raw_sql': '-- noop'
