@@ -1,9 +1,12 @@
 from dbt.runner import RunManager
 from dbt.logger import GLOBAL_LOGGER as logger  # noqa
-import dbt.utils
+from dbt.node_runners import TestRunner
+from dbt.node_types import NodeType
+import dbt.ui.printer
+from dbt.task.base_task import RunnableTask
 
 
-class TestTask:
+class TestTask(RunnableTask):
     """
     Testing:
         1) Create tmp views w/ 0 rows to ensure all tables, schemas, and SQL
@@ -14,10 +17,6 @@ class TestTask:
            c) referential integrity
            d) accepted value
     """
-    def __init__(self, args, project):
-        self.args = args
-        self.project = project
-
     def run(self):
         runner = RunManager(
             self.project, self.project['target-path'], self.args)
@@ -25,17 +24,26 @@ class TestTask:
         include = self.args.models
         exclude = self.args.exclude
 
+        query = {
+            "include": self.args.models,
+            "exclude": self.args.exclude,
+            "resource_types": NodeType.Test
+        }
+
         test_types = [self.args.data, self.args.schema]
 
         if all(test_types) or not any(test_types):
-            results = runner.run_tests(include, exclude, set())
+            tags = set()
         elif self.args.data:
-            results = runner.run_tests(include, exclude, {'data'})
+            tags = {'data'}
         elif self.args.schema:
-            results = runner.run_tests(include, exclude, {'schema'})
+            tags = {'schema'}
         else:
             raise RuntimeError("unexpected")
 
-        logger.info(dbt.utils.get_run_status_line(results))
+        query['tags'] = tags
+        results = runner.run_flat(query, TestRunner)
+
+        dbt.ui.printer.print_run_end_messages(results)
 
         return results
