@@ -2,6 +2,7 @@ from dbt.logger import GLOBAL_LOGGER as logger
 from dbt import version as dbt_version
 from snowplow_tracker import Subject, Tracker, Emitter, logger as sp_logger
 from snowplow_tracker import SelfDescribingJson, disable_contracts
+from datetime import datetime
 
 import platform
 import uuid
@@ -10,6 +11,8 @@ import os
 import json
 import logging
 
+import dbt.clients.system
+
 disable_contracts()
 sp_logger.setLevel(100)
 
@@ -40,7 +43,8 @@ class User(object):
         self.do_not_track = True
 
         self.id = None
-        self.invocation_id = None
+        self.invocation_id = str(uuid.uuid4())
+        self.run_started_at = datetime.now()
 
     def state(self):
         return "do not track" if self.do_not_track else "tracking"
@@ -48,8 +52,6 @@ class User(object):
     def initialize(self):
         self.do_not_track = False
 
-        self.invocation_id = str(uuid.uuid4())
-
         cookie = self.get_cookie()
         self.id = cookie.get('id')
 
@@ -61,8 +63,7 @@ class User(object):
         cookie_dir = os.path.dirname(COOKIE_PATH)
         user = {"id": str(uuid.uuid4())}
 
-        if not os.path.exists(cookie_dir):
-            os.makedirs(cookie_dir)
+        dbt.clients.system.make_directory(cookie_dir)
 
         with open(COOKIE_PATH, "w") as fh:
             yaml.dump(user, fh)
