@@ -1,11 +1,15 @@
 import os
 import json
+import hashlib
+import itertools
 
-import dbt.project
 from dbt.include import GLOBAL_DBT_MODULES_PATH
-
 from dbt.compat import basestring
 from dbt.logger import GLOBAL_LOGGER as logger
+from dbt.node_types import NodeType
+
+import dbt.clients.jinja
+
 
 DBTConfigKeys = [
     'enabled',
@@ -21,20 +25,10 @@ DBTConfigKeys = [
 ]
 
 
-class NodeType(object):
-    Base = 'base'
-    Model = 'model'
-    Analysis = 'analysis'
-    Test = 'test'
-    Archive = 'archive'
-    Macro = 'macro'
-    Operation = 'operation'
-
-
-class RunHookType:
-    Start = 'on-run-start'
-    End = 'on-run-end'
-    Both = [Start, End]
+class ExitCodes(object):
+    Success = 0
+    ModelError = 1
+    UnhandledError = 2
 
 
 class This(object):
@@ -155,7 +149,13 @@ def find_macro_by_name(flat_graph, target_name, target_package):
 def find_by_name(flat_graph, target_name, target_package, subgraph,
                  nodetype):
     for name, model in flat_graph.get(subgraph).items():
-        resource_type, package_name, node_name = name.split('.')
+        node_parts = name.split('.')
+        if len(node_parts) != 3:
+            node_type = model.get('resource_type', 'node')
+            msg = "{} names cannot contain '.' characters".format(node_type)
+            dbt.exceptions.raise_compiler_error(model, msg)
+
+        resource_type, package_name, node_name = node_parts
 
         if (resource_type == nodetype and
             ((target_name == node_name) and
@@ -177,6 +177,7 @@ def find_model_by_fqn(models, fqn):
 
 
 def dependency_projects(project):
+    import dbt.project
     module_paths = [
         GLOBAL_DBT_MODULES_PATH,
         os.path.join(project['project-root'], project['modules-path'])
@@ -209,7 +210,6 @@ def dependency_projects(project):
 
 
 def split_path(path):
-    norm = os.path.normpath(path)
     return path.split(os.sep)
 
 
@@ -276,22 +276,6 @@ def get_pseudo_hook_path(hook_name):
     return os.path.join(*path_parts)
 
 
-def get_run_status_line(results):
-    total = len(results)
-    errored = len([r for r in results if r.errored or r.failed])
-    skipped = len([r for r in results if r.skipped])
-    passed = total - errored - skipped
-
-    return (
-        "Done. PASS={passed} ERROR={errored} SKIP={skipped} TOTAL={total}"
-        .format(
-            total=total,
-            passed=passed,
-            errored=errored,
-            skipped=skipped
-        ))
-
-
 def get_nodes_by_tags(nodes, match_tags, resource_type):
     matched_nodes = []
     for node in nodes:
@@ -299,3 +283,15 @@ def get_nodes_by_tags(nodes, match_tags, resource_type):
         if len(node_tags & match_tags):
             matched_nodes.append(node)
     return matched_nodes
+
+
+def get_hash(model):
+    return hashlib.md5(model.get('unique_id').encode('utf-8')).hexdigest()
+
+
+def get_hashed_contents(model):
+    return hashlib.md5(model.get('raw_sql').encode('utf-8')).hexdigest()
+
+
+def flatten_nodes(dep_list):
+    return list(itertools.chain.from_iterable(dep_list))
